@@ -144,7 +144,7 @@ def fastaAAIterator(file,tagparser=_parseFastaTag):
     '''
     return fastaIterator(file, AASequence,tagparser)
 
-def formatFasta(data,gbmode=False,upper=False):
+def formatFasta(data,gbmode=False,upper=False,restrict=None):
     '''
     Convert a seqence or a set of sequences in a
     string following the fasta format
@@ -158,11 +158,20 @@ def formatFasta(data,gbmode=False,upper=False):
                    sequence indexing with the blast formatdb command.
     @type gbmode: bool
                 
+    @param restrict: a set of key name that will be print in the formated
+                     output. If restrict is set to C{None} (default) then
+                     all keys are formated.
+    @type restrict: any iterable value or None
+    
     @return: a fasta formated string
     @rtype: str
     '''
     if isinstance(data, BioSequence):
         data = [data]
+
+    if restrict is not None and not isinstance(restrict, set):
+        restrict = set(restrict)    
+
     rep = []
     for sequence in data:
         seq = str(sequence)
@@ -174,7 +183,9 @@ def formatFasta(data,gbmode=False,upper=False):
             frgseq = '\n'.join([seq[x:x+60].upper() for x in xrange(0,len(seq),60)])
         else:
             frgseq = '\n'.join([seq[x:x+60] for x in xrange(0,len(seq),60)])
-        info='; '.join(['%s=%s' % x for x in sequence.rawiteritems()])
+        info='; '.join(['%s=%s' % x 
+                        for x in sequence.rawiteritems()
+                        if restrict is None or x[0] in restrict])
         if info:
             info=info+';'
         id = sequence.id
